@@ -1,4 +1,3 @@
-use bytes::Bytes;
 use std::{
     borrow::Cow,
     error::Error as StdError,
@@ -13,7 +12,7 @@ pub type ClientResult<T, TransportError> = Result<T, ClientError<TransportError>
 
 /// Errors that can occur within `Client` operation.
 #[derive(Debug)]
-pub enum ClientError<TransportError: StdError> {
+pub enum ClientError<TransportError> {
     /// Occurs if an endpoint returns an error.
     EndpointError {
         /// The hRPC error.
@@ -24,11 +23,13 @@ pub enum ClientError<TransportError: StdError> {
     /// Occurs if the data server responded with could not be decoded.
     MessageDecode(DecodeBodyError),
     /// Occurs if the data server responded with is not supported for decoding.
-    ContentNotSupported(Bytes),
+    ContentNotSupported,
     /// Occurs if an IO error is returned.
     Io(IoError),
     /// Occures if the underlying transport yields an error.
     Transport(TransportError),
+    /// Occurs if the spec implemented on server doesn't match ours.
+    IncompatibleSpecVersion,
 }
 
 impl<TransportError: StdError> Display for ClientError<TransportError> {
@@ -42,7 +43,7 @@ impl<TransportError: StdError> Display for ClientError<TransportError> {
                 "endpoint {} returned an error '{}': {}",
                 endpoint, hrpc_error.identifier, hrpc_error.human_message,
             ),
-            ClientError::ContentNotSupported(_) => {
+            ClientError::ContentNotSupported => {
                 write!(f, "server responded with a non protobuf response")
             }
             ClientError::MessageDecode(err) => write!(
@@ -52,17 +53,20 @@ impl<TransportError: StdError> Display for ClientError<TransportError> {
             ),
             ClientError::Io(err) => write!(f, "io error: {}", err),
             ClientError::Transport(err) => write!(f, "transport error: {}", err),
+            ClientError::IncompatibleSpecVersion => {
+                write!(f, "server hrpc version is incompatible with ours")
+            }
         }
     }
 }
 
-impl<TransportError: StdError> From<DecodeBodyError> for ClientError<TransportError> {
+impl<TransportError> From<DecodeBodyError> for ClientError<TransportError> {
     fn from(err: DecodeBodyError) -> Self {
         ClientError::MessageDecode(err)
     }
 }
 
-impl<TransportError: StdError> From<IoError> for ClientError<TransportError> {
+impl<TransportError> From<IoError> for ClientError<TransportError> {
     fn from(err: IoError) -> Self {
         ClientError::Io(err)
     }
